Acrylic Beads - Plastic Beads - Fire Mountain Gems and Beads
Description: Acrylic, plastic & resin beads create brilliantly colored & lightweight jewelry: flower beads, large faceted 'crystal' beads, Japanese Tensha beads & more!

- 800-355-2137

- Login
- Create Account
- Favorites List

Close
Email:
Password:
Remember Me
Forgot Your Password? Need Help?
? If you are still having trouble signing in, click here.
0 items
Home
Deal of the Day FREE Catalog
Browse

### Refine Your Results

#### Filters

- Regular Stock (805)
- Limited Quantity (5,078)
- New Items (1,330)

#### Category

- Pearls (73)
- Spacer Beads (41)

#### Brand

- Cool Frost Resin Beads (60)
- Blue Moon Beads (32)
- Swarovski (27)
- Dione (20)
- Bead Huggers (10)
- More...

- Bead Landing (9)
- Laliberi (8)
- Circle of Hope (4)
- Shimmer (3)
- Bead Party (1)

#### Collections

- Assortments and Mixes (190)
- Christmas (30)
- Add A Bead System (22)
- Sports Collection (11)
- Awareness and Causes (8)
- More...

- Wedding Collection (1)
- Birthstones (1)

#### Material

- Acrylic (5,122)
- Epoxy/Resin (256)
- Rubberized Acrylic (206)
- Other Plastics (200)
- Polymer Clay (76)
- More...

- Lucite (17)
- Silicone (6)

#### Color

- Blues (717)
- Greens (600)
- Browns / Tans (432)
- Whites (424)
- Oranges / Peaches (411)
- More...

- Pinks (411)
- Purples / Lavenders (385)
- Reds (367)
- Blacks (363)
- Clear (307)
- Multicolored (277)
- Yellows (249)
- Beige / Cream (198)
- Gold (189)
- Silver (189)
- Mixed Colors (159)
- Greys (151)
- Copper (52)

#### Shape

- Round (2,579)
- Oval (872)
- Tube (407)
- Rondelle (341)
- Teardrop (321)
- More...

- Hearts (246)
- Chips and Nuggets (180)
- Rectangle / Brick (163)
- Plant (158)
- Square (143)
- Polygons (74)
- Diamond (66)
- Animal (55)
- Double Cone (52)
- Other Shapes (41)
- Mixed Shapes (39)
- Celestial (35)
- Triangular (32)
- Cone (20)
- Religion (14)
- People (11)
- Bicone (11)
- Symbols/Characters (4)
- Cathedral (2)

#### Stringing Length

- Graduated (4)
- Mixed Sizes (70)
- 1mm (6)
- 2mm (22)
- 3mm (110)
- More...

- 4mm (143)
- 5mm (71)
- 6mm (360)
- 7mm (103)
- 8mm (380)
- 9mm (77)
- 10mm (343)
- 11mm (108)
- 12mm (543)
- 13mm (115)
- 14mm (469)
- 15mm (117)
- 16mm (296)
- 17mm (137)
- 18mm (374)
- 19mm (140)
- 20mm (210)
- 21mm (46)
- 22mm (121)
- 23mm (57)
- 24mm (89)
- 25mm & Up (801)

#### Embellishment

- Smooth (1,847)
- Faceted (702)
- Textured (340)
- Puffed (337)
- Flat (239)
- More...

- Twisted (104)
- Antiqued (100)
- Corrugated (90)
- Irregular (59)
- Fancy (52)
- Open (50)
- Carved (49)
- Beaded (23)
- Fluted (23)
- Curved (16)
- Rounded (13)
- Rough (9)
- Freeform (8)
- Dimpled (8)
- Modified (7)
- Bumpy (6)
- Wavy (5)
- Ribbed (1)
- Swirled (1)

#### Multi Hole/Loop

- 2-Strand (8)
- 3-Strand (1)

#### Drill Orientation

- Half-Drilled (32)
- Lentil-Drilled (18)
- Top-Drilled (7)

#### Price

- Under $5 (4,966)
- $5 to $10 (782)
- $10 to $15 (46)
- $15 to $20 (56)
- $20 to $25 (1)
- $25 to $50 (16)
- $50 to $100 (7)
- $100 and Over (9)

Price Range:
–

# Acrylic, Resin and More "Created" Beads

With a wide range of popular colorful choices that includes faceted, flower and alphabet--acrylic beads combine eye-catching beauty with economy and are a lightweight alternative to glass. More choices include plastic and pony beads.

## Shop by Color

Blues
Greens
Browns
Whites
Oranges
Pinks
Purples
Reds
Blacks
Clear
Multi
Yellows
Beige
Gold
Silver
Mixed
Greys
Copper

## Shop by Shape

Round
Oval
Tube
Rondelle
Teardrop
Hearts
Chips
Rectangle
Plant
Square
Polygons
Diamond
Animal
Double Cone
Other
Mixed
Celestial
Triangular
Cone
Religion
People
Bicone
Symbols
Cathedral

## Shop by Style

#### Faceted Beads

- Round Faceted Beads
- Oval Faceted Beads
- Shop More

#### Wonder Beads

#### Crow and Pony Beads

#### Alphabet Beads

#### Bead Mixes

#### Polymer Clay Beads

#### Multi-Colored Resin

#### Rubberized Beads

#### Color Changing

#### Metalized Beads

#### Metallic Beads

#### Metallic Enhanced

#### Enameled Beads

#### Carved Style

#### Razzleberry Beads

#### Marbled and Speckled Beads

#### Striped Beads

#### Patterned Beads

## Shop Popular Brands

#### Cool Frost

#### Dione Large Hole Beads

#### Swarovski

## Shop Popular Themes

#### Halloween Beads

#### Christmas Beads

#### Spring Beads

#### Sports Beads

#### Floral Beads

#### Valentines Beads

## Components and Findings

#### Focals and Components

- Flowers
- Leaves
- Shop All

#### Charms

#### Cabochons

#### Links

#### Clasps

#### Chain

Q.

How do you care for silver (not real) coated acrylic beads. I had someone use CLR, which discolored the beads. I guess I need to provide instructions but I'm not sure what would be the best way to clean them, or is there some way I can coat them to provide extra protection. Thanks.

  A. Read the Answer
Q.

I use a lot of acrylic beads in my designs, especially "pony" beads. I notice that a lot of them have excess plastic and rough edges left over from the manufacturing process. I was wondering what is the fastest and most effective way to file down these rough spots. Is it possible to use a rock tumbler for greater speed?

  A. Read the Answer

## Popular Searches

- Half-Drilled
- Lucite

- Acrylic Rhinestones

- Evil Eye

## Sign up for Email Offers

- New Product Announcements
- Sale Announcements
- Beading News and More...